marktools.detach_articulations_attached_to_component
====================================================

.. autofunction:: abjad.tools.marktools.detach_articulations_attached_to_component.detach_articulations_attached_to_component
